@@ -275,6 +275,8 @@
 #define __NR_pkey_free 290
 #define __NR_statx 291
 #define __NR_io_pgetevents 292
+#define __NR_rseq 293
+#define __NR_kexec_file_load 294
 
 #define SYS_io_setup 0
 #define SYS_io_destroy 1
@@ -553,3 +555,5 @@
 #define SYS_pkey_free 290
 #define SYS_statx 291
 #define SYS_io_pgetevents 292
+#define SYS_rseq 293
+#define SYS_kexec_file_load 294
